lubridate package, some additional functions
to work with times are provided.This function takes a numeric with a "unit" attribute and converts it to
another numeric with a different time attribute.
If the units passed to argument units are the same as
attr(time, "unit"), then it simply returns input time.
inSeconds(unit)## S3 method for class 'character':
inSeconds(unit)
## S3 method for class '`NULL`':
inSeconds(unit)
convertTimeunit(time, unit)
## S3 method for class 'numeric,character':
convertTimeunit(time, unit)
## S3 method for class 'numeric,missing':
convertTimeunit(time)
.spadesTimes
spadesTimes()
SpaDES.unit attribute set to
"seconds".character of length 6.spadesTimes() function.If time has no units attribute, then it is assumed to be
seconds.