spadesClasses: Classes defined in SpaDES
Description
These S4 classes are defined within SpaDES. "dot" classes are not exported and
are therefore intended for internal use only.Simulation classes
ll{
simList The 'simList' class
.moduleDeps Descriptor object for specifying SpaDES module dependecies
.simDeps Defines all simulation dependencies for all modules within a SpaDES simulation
--------------------------- ------------------------------------------------------------------------------------------
}Plotting classes - used within <code>Plot</code>
ll{
New classes
.spadesPlot Main class for Plot - contains .spadesGrob and .arrangement objects
.spadesGrob GRaphical OBject used by SpaDES - smallest unit
.arrangement The layout or "arrangement" of plot objects
--------------------------- ------------------------------------------------------------------------------------------
}
ll{
Unions of existing classes
.spadesPlottables The union of all object classes Plot can accept
.spadesPlotObjects The union of .spatialObjects and several others
.spatialObjects The union of several spatial classes
--------------------------- ------------------------------------------------------------------------------------------
}