spadesMaps: Dummy maps included with SpaDES
Description
All maps included with SpaDES are randomly generated maps created by gaussMap().
These are located within the maps folder of the package, and are used in the vignettes.
Use system.file(package="SpaDES", "maps") to locate the maps directory on your system.Details
DEM.tif: converted to a a small number of discrete levels (in 100m hypothetical units)
habitatQuality.tif: made to look like a continuous habitat surface, rescaled to 0 to 1
forestAge.tif: rescaled to possible forest ages in a boreal forest setting
forestCover.tif: rescaled to possible forest cover in a boreal forest setting
percentPine.tif: rescaled to percentages.